@@ -41,6 +41,7 @@
 
 #include "quick-desktop-reader.h"
 
+#include "egg-screen-exec.h"
 #include "egg-screen-url.h"
 
 #undef LAUNCHER_DEBUG
@@ -100,7 +101,7 @@ launch_url (Launcher *launcher)
 		return;
 	}
 
-	egg_screen_url_show (screen, url, &error);
+	egg_url_show_on_screen (url, screen, &error);
 	if (error) {
 		panel_error_dialog (
 			screen,
@@ -131,8 +132,8 @@ launch_cb (GtkWidget *widget,
 	else {
 		GError *error = NULL;
 
-		panel_ditem_launch (launcher_get_screen (launcher),
-				    item, NULL, 0, &error);
+		panel_ditem_launch (
+			item, NULL, 0, launcher_get_screen (launcher), &error);
 		if (error) {
 			panel_error_dialog (
 				launcher_get_screen (launcher),
@@ -172,11 +173,20 @@ drag_data_received_cb (GtkWidget        *widget,
 		       Launcher         *launcher)
 {
 	GError *error = NULL;
+	char **envp = NULL;
+
+	GdkScreen *screen = launcher_get_screen (launcher);
+
+	if (gdk_screen_get_default () != screen)
+		envp = egg_screen_exec_environment (screen);
+
+	gnome_desktop_item_drop_uri_list_with_env (launcher->ditem,
+						   (const char *)selection_data->data,
+						   0 /* flags */,
+						   envp,
+						   &error);
+	g_strfreev (envp);
 
-	gnome_desktop_item_drop_uri_list (launcher->ditem,
-					  (const char *)selection_data->data,
-					  0 /* flags */,
-					  &error);
 	if (error) {
 		panel_error_dialog (
 			launcher_get_screen (launcher),
@@ -414,6 +424,7 @@ create_launcher (const char *parameters, GnomeDesktopItem *ditem)
 	launcher->button = NULL;
 	launcher->dedit = NULL;
 	launcher->prop_dialog = NULL;
+	launcher->destroy_handler = 0;
 
 	/* Icon will be setup later */
 	launcher->button = button_widget_new (NULL /* icon */,
@@ -454,9 +465,11 @@ create_launcher (const char *parameters, GnomeDesktopItem *ditem)
 			   G_CALLBACK (drag_leave_cb), launcher);
 	g_signal_connect (launcher->button, "clicked",
 			  G_CALLBACK (launch_cb), launcher);
-	g_signal_connect (launcher->button, "destroy",
-			  G_CALLBACK (destroy_launcher), launcher);
 
+	launcher->destroy_handler =
+			g_signal_connect (launcher->button, "destroy",
+					  G_CALLBACK (destroy_launcher),
+					  launcher);
 	launcher->ditem = ditem;
 
 	return launcher;
